@@ -37,17 +37,18 @@
 #include <kaboutdata.h>
 #include <kdialog.h>
 #include <kstandarddirs.h>
-#include <k3process.h>
+#include <kprocess.h>
 #include <kapplication.h>
 #include <ktemporaryfile.h>
 #include <kurlrequester.h>
 #include <kmessagebox.h>
-#include <k3listview.h>
+#include <qtreewidget.h>
 #include <klineedit.h>
 
 #include <QtDBus/QtDBus>
 #include <QLabel>
 #include <QLayout>
+#include <QHeaderView>
 #include <QProgressBar>
 #include <QTextEdit>
 
@@ -213,7 +214,9 @@ void IndexProgressDialog::hideDetails()
   mLogLabel->hide();
   mLogView->hide();
   setButtonText( User1, i18n("Details &gt;&gt;") );
-  layout()->activate();
+
+  // causes bug 166343
+  //layout()->activate();
   adjustSize();
 }
 
@@ -267,23 +270,23 @@ void KCMHelpCenter::setupMainWidget( QWidget *parent )
   topLayout->setSpacing( KDialog::spacingHint() );
 
   QString helpText =
-    i18n("To be able to search a document, there needs to exist a search\n"
-         "index. The status column of the list below shows, if an index\n"
+    i18n("To be able to search a document, a search\n"
+         "index needs to exist. The status column of the list below shows whether an index\n"
          "for a document exists.\n") +
-    i18n("To create an index check the box in the list and press the\n"
+    i18n("To create an index, check the box in the list and press the\n"
          "\"Build Index\" button.\n");
 
   QLabel *label = new QLabel( helpText, parent );
   topLayout->addWidget( label );
 
-  mListView = new K3ListView( parent );
-  mListView->setFullWidth( true );
-  mListView->addColumn( i18n("Search Scope") );
-  mListView->addColumn( i18n("Status") );
-  mListView->setColumnAlignment( 1, Qt::AlignCenter );
+  mListView = new QTreeWidget( parent );
+  //mListView->setFullWidth( true );
+  mListView->setColumnCount(2);
+  mListView->setHeaderLabels( QStringList() << i18n("Search Scope") << i18n("Status") );
   topLayout->addWidget( mListView );
-  connect( mListView, SIGNAL( clicked( Q3ListViewItem * ) ),
-    SLOT( checkSelection() ) );
+  // not just itemClicked, so that Key_Space also triggers it (#123954)
+  connect( mListView, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
+           SLOT(checkSelection()) );
 
   QBoxLayout *urlLayout = new QHBoxLayout();
   topLayout->addLayout( urlLayout );
@@ -343,14 +346,16 @@ void KCMHelpCenter::load()
     }
   }
 
+  mListView->header()->setResizeMode( QHeaderView::ResizeToContents );
+
   updateStatus();
 }
 
 void KCMHelpCenter::updateStatus()
 {
-  Q3ListViewItemIterator it( mListView );
-  while ( it.current() != 0 ) {
-    ScopeItem *item = static_cast<ScopeItem *>( it.current() );
+  QTreeWidgetItemIterator it( mListView );
+  while ( (*it) != 0 ) {
+    ScopeItem *item = static_cast<ScopeItem *>( (*it) );
     QString status;
     if ( item->entry()->indexExists( Prefs::indexDirectory() ) ) {
       status = i18nc("Describes the status of a documentation index that is present", "OK");
@@ -394,9 +399,9 @@ bool KCMHelpCenter::buildIndex()
 
   bool hasError = false;
 
-  Q3ListViewItemIterator it( mListView );
-  while ( it.current() != 0 ) {
-    ScopeItem *item = static_cast<ScopeItem *>( it.current() );
+  QTreeWidgetItemIterator it( mListView );
+  while ( (*it) != 0 ) {
+    ScopeItem *item = static_cast<ScopeItem *>( (*it) );
     if ( item->isOn() ) {
       DocEntry *entry = item->entry();
 
@@ -408,12 +413,16 @@ bool KCMHelpCenter::buildIndex()
           i18n("No document type.") );
         hasError = true;
       } else {
+        QString error;
         SearchHandler *handler = mEngine->handler( entry->documentType() );
         if ( !handler ) {
           KMessageBox::sorry( this, docText +
             i18n("No search handler available for document type '%1'.",
               entry->documentType() ) );
           hasError = true;
+        } else if ( !handler->checkPaths( &error ) ) {
+          KMessageBox::sorry( this, docText + error );
+          hasError = true;
         } else {
           QString indexer = handler->indexCommand( entry->identifier() );
           if ( indexer.isEmpty() ) {
@@ -446,11 +455,11 @@ bool KCMHelpCenter::buildIndex()
     return !hasError;
   }
 
-  mCurrentEntry = mIndexQueue.begin();
+  mCurrentEntry = mIndexQueue.constBegin();
   QString name = (*mCurrentEntry)->name();
 
   if ( !mProgressDialog ) {
-    mProgressDialog = new IndexProgressDialog( this );
+    mProgressDialog = new IndexProgressDialog( parentWidget() );
     connect( mProgressDialog, SIGNAL( cancelled() ),
              SLOT( cancelBuildIndex() ) );
     connect( mProgressDialog, SIGNAL( closed() ),
@@ -470,27 +479,40 @@ void KCMHelpCenter::startIndexProcess()
 {
   kDebug() << "KCMHelpCenter::startIndexProcess()";
 
-  mProcess = new K3Process;
-
+  mProcess = new KProcess;
+#ifndef Q_WS_WIN
   if ( mRunAsRoot ) {
-    *mProcess << KStandardDirs::findExe("kdesu"); 
-    kDebug() << "Run as root";
+    QString kdesu = KStandardDirs::findExe("kdesu");
+    if(kdesu.isEmpty()) {
+      kError() << "Failed to run index process as root - could not find kdesu";
+    } else {
+      *mProcess << kdesu;
+      if(parentWidget()) {
+        *mProcess << "--attach" <<  QString::number(parentWidget()->window()->winId());
+        kDebug() << "Run as root, attaching kdesu to winid " << QString::number(parentWidget()->window()->winId());
+      }
+      *mProcess << "--";
+    }
   }
+#endif
 
   *mProcess << KStandardDirs::findExe("khc_indexbuilder");
-  *mProcess << mCmdFile->name();
+  *mProcess << mCmdFile->fileName();
   *mProcess << Prefs::indexDirectory();
 
-  connect( mProcess, SIGNAL( processExited( K3Process * ) ),
-           SLOT( slotIndexFinished( K3Process * ) ) );
-  connect( mProcess, SIGNAL( receivedStdout( K3Process *, char *, int ) ),
-           SLOT( slotReceivedStdout(K3Process *, char *, int ) ) );
-  connect( mProcess, SIGNAL( receivedStderr( K3Process *, char *, int ) ),
-           SLOT( slotReceivedStderr( K3Process *, char *, int ) ) );
+  mProcess->setOutputChannelMode(KProcess::SeparateChannels);
+  connect( mProcess, SIGNAL( readyReadStandardError() ),
+           SLOT( slotReceivedStderr() ) );
+  connect( mProcess, SIGNAL( readyReadStandardOutput() ),
+           SLOT( slotReceivedStdout() ) );
+  connect( mProcess, SIGNAL( finished(int, QProcess::ExitStatus) ),
+           SLOT( slotIndexFinished(int, QProcess::ExitStatus) ) );
 
-  if ( !mProcess->start( K3Process::NotifyOnExit, K3Process::AllOutput ) ) {
-    kError() << "KCMHelpcenter::startIndexProcess(): Failed to start process."
-      << endl;
+  mProcess->start();
+  if (!mProcess->waitForStarted()) {
+    kError() << "KCMHelpcenter::startIndexProcess(): Failed to start process.";
+    deleteProcess();
+    deleteCmdFile();
   }
 }
 
@@ -507,21 +529,11 @@ void KCMHelpCenter::cancelBuildIndex()
   }
 }
 
-void KCMHelpCenter::slotIndexFinished( K3Process *proc )
+void KCMHelpCenter::slotIndexFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
   kDebug() << "KCMHelpCenter::slotIndexFinished()";
 
-  if ( proc == 0 ) {
-    kWarning() << "Process null." ;
-    return;
-  }
-
-  if ( proc != mProcess ) {
-    kError() << "Unexpected Process finished." << endl;
-    return;
-  }
-
-  if ( mProcess->normalExit() && mProcess->exitStatus() == 2 ) {
+  if ( exitStatus == QProcess::NormalExit && exitCode == 2 ) {
     if ( mRunAsRoot ) {
       kError() << "Insufficient permissions." << endl;
     } else {
@@ -531,8 +543,8 @@ void KCMHelpCenter::slotIndexFinished( K3Process *proc )
       startIndexProcess();
       return;
     }
-  } else if ( !mProcess->normalExit() || mProcess->exitStatus() != 0 ) {
-    kDebug() << "K3Process reported an error.";
+  } else if ( exitStatus != QProcess::NormalExit || exitCode != 0 ) {
+    kDebug() << "KProcess reported an error.";
     KMessageBox::error( this, i18n("Failed to build index.") );
   } else {
     mConfig->group( "Search" ).writeEntry( "IndexExists", true );
@@ -603,17 +615,17 @@ void KCMHelpCenter::advanceProgress()
   if ( mProgressDialog && mProgressDialog->isVisible() ) {
     mProgressDialog->advanceProgress();
     mCurrentEntry++;
-    if ( mCurrentEntry != mIndexQueue.end() ) {
+    if ( mCurrentEntry != mIndexQueue.constEnd() ) {
       QString name = (*mCurrentEntry)->name();
       mProgressDialog->setLabelText( name );
     }
   }
 }
 
-void KCMHelpCenter::slotReceivedStdout( K3Process *, char *buffer, int buflen )
+void KCMHelpCenter::slotReceivedStdout()
 {
-  QString text = QString::fromLocal8Bit( buffer, buflen );
-  int pos = text.lastIndexOf( QLatin1Char('\n') );
+  QByteArray text= mProcess->readAllStandardOutput();
+  int pos = text.lastIndexOf( '\n' );
   if ( pos < 0 ) {
     mStdOut.append( text );
   } else {
@@ -624,10 +636,10 @@ void KCMHelpCenter::slotReceivedStdout( K3Process *, char *buffer, int buflen )
   }
 }
 
-void KCMHelpCenter::slotReceivedStderr( K3Process *, char *buffer, int buflen )
+void KCMHelpCenter::slotReceivedStderr( )
 {
-  QString text = QString::fromLocal8Bit( buffer, buflen );
-  int pos = text.lastIndexOf( QLatin1Char('\n') );
+  QByteArray text = mProcess->readAllStandardError();
+  int pos = text.lastIndexOf( '\n' );
   if ( pos < 0 ) {
     mStdErr.append( text );
   } else {
@@ -666,9 +678,9 @@ void KCMHelpCenter::checkSelection()
 {
   int count = 0;
 
-  Q3ListViewItemIterator it( mListView );
-  while ( it.current() != 0 ) {
-    ScopeItem *item = static_cast<ScopeItem *>( it.current() );
+  QTreeWidgetItemIterator it( mListView );
+  while ( (*it) != 0 ) {
+    ScopeItem *item = static_cast<ScopeItem *>( (*it) );
     if ( item->isOn() ) {
       ++count;
     }
