@@ -31,7 +31,6 @@
 #include "kio_smb_internal.h"
 #include "kio_smb.h"
 
-#include <QTextCodec>
 
 #include <kconfig.h>
 #include <kglobal.h>
@@ -80,21 +79,12 @@ void SMBUrl::updateCache()
 
     // SMB URLs are UTF-8 encoded
     kDebug(KIO_SMB) << "updateCache " << KUrl::path();
-    if (KUrl::url() == "smb:/")
-        m_surl = "smb://";
-    else {
-        QString surl = "smb://";
-        if (KUrl::hasUser()) {
-            surl += QUrl::fromPercentEncoding(KUrl::user().toLatin1());
-            if (KUrl::hasPass()) {
-                surl += ':' + QUrl::fromPercentEncoding(KUrl::pass().toLatin1());
-            }
-            surl += '@';
-        }
-        surl += QUrl::fromPercentEncoding(KUrl::host().toUpper().toLatin1());
-        surl += QUrl::fromPercentEncoding(KUrl::path().toLatin1());
-        m_surl = surl.toUtf8();
-    }
+
+    if ( KUrl::url() == "smb:/" )
+      m_surl = "smb://";
+    else
+      m_surl = KUrl::url( RemoveTrailingSlash ).toUtf8();
+    
     m_type = SMBURLTYPE_UNKNOWN;
     // update m_type
     (void)getType();
