@@ -19,18 +19,15 @@
 #ifndef _NEPOMUK_STRIGI_SYSTRAY_H_
 #define _NEPOMUK_STRIGI_SYSTRAY_H_
 
-#include <knotificationitem.h>
+#include <KStatusNotifierItem>
 
 class KToggleAction;
 
-using namespace Experimental;
-
 namespace Nepomuk {
 
-    class IndexScheduler;
     class StrigiService;
 
-    class SystemTray : public KNotificationItem
+    class SystemTray : public KStatusNotifierItem
     {
         Q_OBJECT
 
@@ -41,11 +38,13 @@ namespace Nepomuk {
     private Q_SLOTS:
         void slotUpdateStrigiStatus();
         void slotConfigure();
+        void slotSuspend( bool suspended );
 
     private:
         KToggleAction* m_suspendResumeAction;
 
         StrigiService* m_service;
+        bool m_suspendedManually;
     };
 }
 
